from .widget import GoatBar

__all__ = [
    # Main class
    "GoatBar",
]
